# Pioneers in the information age!

# ITGeeker.net toolbox.

### 信息时代弄潮儿! 技术奇客的工具箱


# Update log:

2025-11-06 v0.2.6
1. Add Chinese ID check function, fixed former bug.
2. Add convert number to Chinese RMB.